@@ -150,16 +150,16 @@ main(int argc, char *argv[])
 	    if (comm && strcmp(comm, task->comm) != 0)
 		continue;
 	    if (!all)
-		show_inode(task, task->root, -1);
-	    show_inode(task, task->pwd, -2);
+		show_inode(task, task->fs->root, -1);
+	    show_inode(task, task->fs->pwd, -2);
 	    show_inode(task, task->executable, -3);
-	    for (vmm = task->mmap; vmm; vmm = vm.vm_next) {
+	    for (vmm = task->mm->mmap; vmm; vmm = vm.vm_next) {
 		kmemread(&vm, (unsigned long) vmm, sizeof vm);
 		if (vm.vm_inode)
 		    show_inode(task, vm.vm_inode, -4);
 	    }
 	    for (i = 0; i < NR_OPEN; ++i) {
-		if ((tmp = task->filp[i])) {
+		if ((tmp = task->files->fd[i])) {
 		    if (mmap_page((unsigned long) tmp) < 0 && verbose)
 			    printf("mmap_page failed\n");
 		    filep = KPTR(tmp);
@@ -250,9 +250,9 @@ show_inode(struct task_struct *task, struct inode *ino, int type)
 	    _read_pipe_fops = k_addr("_read_pipe_fops");
 	    _write_pipe_fops = k_addr("_write_pipe_fops");
 	}
-	if ((long)((struct file *)KPTR(task->filp[type]))->f_op == _read_pipe_fops)
+	if ((long)((struct file *)KPTR(task->files->fd[type]))->f_op == _read_pipe_fops)
 	    rw = "<-";
-	else if ((long)((struct file *)KPTR(task->filp[type]))->f_op == _write_pipe_fops)
+	else if ((long)((struct file *)KPTR(task->files->fd[type]))->f_op == _write_pipe_fops)
 	    rw = "->";
 	printf("* (pipe %s %#lx %d %dr %dw)\n",
 	       rw, (unsigned long) PIPE_BASE(*inop),
@@ -263,13 +263,13 @@ show_inode(struct task_struct *task, struct inode *ino, int type)
 	print_sock(ino);
 	return;
     }
-    printf(" %2d,%-2d %5d ", 
+    printf(" %2d,%-2d %5ld ", 
 	major(inop->i_dev), minor(inop->i_dev), inop->i_ino);
 
     if (S_ISCHR(inop->i_mode) || S_ISBLK(inop->i_mode))
 	printf("%3d,%3d ", major(inop->i_rdev), minor(inop->i_rdev));
     else
-	printf("%7d ", inop->i_size);
+	printf("%7ld ", inop->i_size);
 
     if (numeric)
 	printf("%7o ", inop->i_mode);
