@@ -303,7 +303,7 @@ show_procs(void)
 		continue;
 
 	    if (task_buf.pid == 0)
-		task_buf.rss = 0;
+		task_buf.mm->rss = 0;
 
 	    if (npid) {
 		for (j = 0; j < npid; ++j)
@@ -445,7 +445,7 @@ show_short(char *s, struct task_struct *task, reg_t *stack)
 void
 show_long(char *s, struct task_struct *task, reg_t *stack)
 {
-    sprintf(s, "%5d %5d %5d %3d %3d %4d %4d %-10.10s %-5s %-7s ",
+    sprintf(s, "%5d %5d %5ld %3ld %3ld %4ld %4ld %-10.10s %-5s %-7s ",
 	task->euid,
 	task->pid,
 	get_kword((unsigned long) &task->p_pptr->pid),
@@ -457,7 +457,7 @@ show_long(char *s, struct task_struct *task, reg_t *stack)
 	PZERO - task->priority,		/* nice value */
 #endif
 	VSIZE(task,stack),
-	task->rss * 4,
+	task->mm->rss * 4,
 	(task->state == TASK_INTERRUPTIBLE ||
 	 task->state == TASK_UNINTERRUPTIBLE ||
 	 (Debug > 1 && task->state == TASK_STOPPED) ? 
@@ -469,7 +469,7 @@ show_long(char *s, struct task_struct *task, reg_t *stack)
 void
 show_jobs(char *s, struct task_struct *task, reg_t *stack)
 {
-    sprintf(s, "%5d %5d %5d %5d %-7s %5d  %-4s %5d ",
+    sprintf(s, "%5ld %5d %5d %5d %-7s %5d  %-4s %5d ",
 	get_kword((unsigned long) &task->p_pptr->pid),
 	task->pid,
 	task->pgrp,
@@ -501,14 +501,14 @@ show_user(char *s, struct task_struct *task, reg_t *stack)
 	pcpu = (double) (task->utime + task->stime) * 1000 / proc_jiffies;
     if (pcpu >= 1000)
 	pcpu = 999;
-    pmem = task->rss * 1000 / nr_pages;
+    pmem = task->mm->rss * 1000 / nr_pages;
 
-    sprintf(s, "%5d %2d.%d %2d.%d %4d %4d %-7s %-5s%.6s ",
+    sprintf(s, "%5d %2d.%d %2d.%d %4ld %4ld %-7s %-5s%.6s ",
 	task->pid,
 	pcpu / 10, pcpu % 10,
 	pmem / 10, pmem % 10,
 	VSIZE(task,stack),
-	task->rss * 4,
+	task->mm->rss * 4,
 	dev_to_tty(TASK_TTY(task)),
 	status(task),
  	ctime(&start) + (time_now - start > 3600*24 ? 4 : 10));
@@ -586,15 +586,15 @@ show_vm(char *s, struct task_struct *task, reg_t *stack)
 	status(task));
     sprint_time(s, task);
     s += strlen(s);
-    s += sprintf(s, " %6d %4d %4d %4d ",
-	task->maj_flt + (Sum ? task->cmaj_flt : 0),
-	task->end_code / 1024,
-	SIZE(task, stack), task->rss*4);
+    s += sprintf(s, " %6ld %4ld %4ld %4ld ",
+	task->mm->maj_flt + (Sum ? task->mm->cmaj_flt : 0),
+	task->mm->end_code / 1024,
+	SIZE(task, stack), task->mm->rss*4);
     if (task->rlim[RLIMIT_RSS].rlim_cur == RLIM_INFINITY)
 	s += sprintf(s, "   xx ");
     else
 	s += sprintf(s, "%5d ", task->rlim[RLIMIT_RSS].rlim_cur / 1024);
-    pmem = task->rss * 1000 / nr_pages;
+    pmem = task->mm->rss * 1000 / nr_pages;
     sprintf(s, "%2d.%d", pmem / 10, pmem % 10);
 }
 
@@ -604,12 +604,12 @@ show_m(char *s, struct task_struct *task, reg_t *stack)
     struct mem_info *mi;
 
     mi = get_mem_info(task);
-    sprintf(s, "%5d %-7s %5d %5d %4d %4d %4d %4d %4d %4d %4d %3d", 
+    sprintf(s, "%5d %-7s %5ld %5ld %4d %4d %4d %4d %4d %4d %4d %3d", 
 	task->pid,
 	dev_to_tty(TASK_TTY(task)),
-	task->maj_flt + (Sum ? task->cmaj_flt : 0),
-	task->min_flt + (Sum ? task->cmin_flt : 0),
-	/*task->end_code / 4096 << pg_shift,*/
+	task->mm->maj_flt + (Sum ? task->mm->cmaj_flt : 0),
+	task->mm->min_flt + (Sum ? task->mm->cmin_flt : 0),
+	/*task->mm->end_code / 4096 << pg_shift,*/
 	mi->trs << pg_shift,
 	mi->drs << pg_shift,
 	mi->size << pg_shift, 
@@ -635,9 +635,9 @@ prtime(char *s, long unsigned int t, long unsigned int rel)
 	t = 0;
     
     if (t > 9999)
-	sprintf(s, "%5d", t / 100);
+	sprintf(s, "%5ld", t / 100);
     else
-	sprintf(s, "%2d.%02d", t / 100, t % 100);
+	sprintf(s, "%2ld.%02ld", t / 100, t % 100);
     return s;
 }
 
@@ -647,13 +647,13 @@ show_regs(char *s, struct task_struct *task, reg_t *stack)
     char time1[16];
     char time2[16];
 
-    s += sprintf(s, "%2x %5d %8x %8x %8x %s %s %-5s %-7s ",
+    s += sprintf(s, "%2lx %5d %8lx %8x %8x %s %s %-5s %-7s ",
 	task->flags,
 	task->pid,
 	/**
-	task->start_code >> 16,
+	task->mm->start_code >> 16,
 	**/
-	task->start_stack,
+	task->mm->start_stack,
 	KSTK_ESP(stack),
 	KSTK_EIP(stack),
 	prtime(time1, task->timeout, jiffies),
@@ -712,7 +712,7 @@ show_syscall(char *s, struct task_struct *task, reg_t *stack)
 {
     int orig_eax;
 
-    s += sprintf(s, "%5d %-7s %-4.4s %8x ",
+    s += sprintf(s, "%5d %-7s %-4.4s %8lx ",
 	task->pid, dev_to_tty(TASK_TTY(task)), status(task), KSTK(EIP, stack));
     orig_eax = KSTK(ORIG_EAX, stack);
     if (task->state != TASK_ZOMBIE && orig_eax > 0)
@@ -721,7 +721,7 @@ show_syscall(char *s, struct task_struct *task, reg_t *stack)
     else if (task->state == TASK_ZOMBIE || Debug <= 1)
 	sprintf(s, "%-30s ", "");
     else
-	sprintf(s, "%d  ax:%x, bx:%x, cx:%x, dx:%x, si:%x, di:%x, bp:%x ",
+	sprintf(s, "%ld  ax:%lx, bx:%lx, cx:%lx, dx:%lx, si:%lx, di:%lx, bp:%lx ",
 	    KSTK(ORIG_EAX, stack), KSTK(EAX, stack), KSTK(EBX, stack),
 	    KSTK(ECX, stack), KSTK(EDX, stack), KSTK(ESI, stack),
 	    KSTK(EDI, stack), KSTK(EBP, stack));
