@@ -37,9 +37,9 @@ extern caddr_t kbase;
 #define	SSIZE(stack)	(KSTK_ESP(stack) ? _SSIZE(stack) : 0)
 
 #define	VSIZE(task,stack) ((task)->pid == 0 ? 0 : \
-			  (((task)->brk + 1023 + SSIZE(stack)) / 1024))
+			  (((task)->mm->brk + 1023 + SSIZE(stack)) / 1024))
 #define	SIZE(task,stack)  ((task)->pid == 0 ? 0 : \
-			  (((task)->brk - (task)->end_code + 1023 + \
+			  (((task)->mm->brk - (task)->mm->end_code + 1023 + \
 			  SSIZE(stack)) / 1024))
 
 #define TASK_TTY(task)	(major((task)->tty) != 0 \
